@@ -22,6 +22,12 @@ ParamType = Literal[
     "mapping_str_str",
     "list_str",
 ]
+InstanceStatus = Literal[
+    "busy_queue",
+    "busy_task",
+    "ready_queue",
+    "ready_task",
+]
 ParamDef = TypedDict('ParamDef', {
     "name": str,
     "help": str,
@@ -69,33 +75,43 @@ NodeTypes = TypedDict('NodeTypes', {
 })
 NodeInfo = TypedDict('NodeInfo', {
     "id": str,
+    "name": str,
     "state_key": Optional[str],
     "type": str,
     "blobs": Dict[str, str],
     "inputs": Dict[str, Tuple[str, str]],
     "state": Optional[int],
-    "config_error": bool,
+    "config_error": Optional[str],
 })
 PipelineList = TypedDict('PipelineList', {
     "pipelines": List[str],
 })
 PipelineInfo = TypedDict('PipelineInfo', {
-    "name": str,
-    "state_publisher": Optional[str],
-    "notify_publisher": Optional[str],
     "company": str,
-    "nodes": List[NodeInfo],
-    "state": str,
     "high_priority": bool,
+    "ins": List[str],
     "is_parallel": bool,
+    "name": str,
+    "nodes": List[NodeInfo],
+    "notify_publisher": Optional[str],
+    "outs": List[Tuple[str, str]],
     "settings": Dict[str, Any],
+    "state_publisher": Optional[str],
+    "state": str,
+})
+BlobInit = TypedDict('BlobInit', {
+    "blob": str,
 })
 PipelineInit = TypedDict('PipelineInit', {
     "pipeline": str,
 })
+PipelineDupResponse = TypedDict('PipelineDupResponse', {
+    "pipeline": str,
+})
 PipelineCreate = TypedDict('PipelineCreate', {
     "pipeline": str,
     "nodes": List[str],
+    "warnings": List[str],
 })
 NodeDef = TypedDict('NodeDef', {
     "id": str,
@@ -121,6 +137,16 @@ Timing = TypedDict('Timing', {
 Timings = TypedDict('Timings', {
     "times": List[Timing],
 })
+NodeTiming = TypedDict('NodeTiming', {
+    "node_name": str,
+    "node_total": float,
+    "node_avg": float,
+    "fns": List[Timing],
+})
+TimingResult = TypedDict('TimingResult', {
+    "pipe_total": float,
+    "nodes": List[Tuple[str, NodeTiming]],
+})
 InCursors = TypedDict('InCursors', {
     "cursors": Dict[str, int],
 })
@@ -141,13 +167,13 @@ CSVList = TypedDict('CSVList', {
 JobList = TypedDict('JobList', {
     "jobs": List[str],
 })
-JobInfoEntries = TypedDict('JobInfoEntries', {  # pylint: disable=invalid-name
+JobInfoEntries = TypedDict('JobInfoEntries', {
     "data": Optional[Tuple[str, str]],
     "performance": Optional[Tuple[str, str]],
     "predictions": Optional[Tuple[str, str]],
     "sources": List[str],
 })
-JobInfo = TypedDict('JobInfo', {  # pylint: disable=invalid-name
+JobInfo = TypedDict('JobInfo', {
     "id": str,
     "name": str,
     "owner": str,
@@ -169,3 +195,38 @@ JSONBlobResponse = TypedDict('JSONBlobResponse', {
 UserColumnsResponse = TypedDict('UserColumnsResponse', {
     "user_columns": List[str],
 })
+ModelSetupResponse = TypedDict('ModelSetupResponse', {
+    "model_info": Dict[str, Any],
+})
+ModelParamsResponse = TypedDict('ModelParamsResponse', {
+    "model_params": Dict[str, Any],
+})
+FlushAllQueuesResponse = TypedDict('FlushAllQueuesResponse', {
+    "success": bool,
+})
+PutNodeBlob = TypedDict('PutNodeBlob', {
+    "key": str,
+    "new_uri": str,
+})
+QueueStatsResponse = TypedDict('QueueStatsResponse', {
+    "active": int,
+    "data": int,
+    "error": int,
+    "extras": Dict[str, int],
+    "restarted": int,
+    "results": int,
+    "total": int,
+})
+QueueStatus = Literal[
+    "waiting",
+    "running",
+    "result",
+    "error",
+    "void",
+]
+DynamicStatusResponse = TypedDict('DynamicStatusResponse', {
+    "status": Dict[str, QueueStatus],
+})
+DynamicResults = TypedDict('DynamicResults', {
+    "results": List[Any],
+})
